@@ -37,7 +37,8 @@ import click_completion
 # local imports here
 import aprsd
 from aprsd import (
-    client, flask, messaging, packets, plugin, stats, threads, trace, utils,
+    client, flask, kissclient, messaging, packets, plugin, stats, threads,
+    trace, utils,
 )
 
 
@@ -194,6 +195,20 @@ def setup_logging(config, loglevel, quiet):
         imap_logger.setLevel(log_level)
         imap_logger.addHandler(fh)
 
+    if (
+        utils.check_config_option(
+            config, ["aprsd", "web", "enabled"],
+            default_fail=False,
+        )
+    ):
+        qh = logging.handlers.QueueHandler(threads.logging_queue)
+        q_log_formatter = logging.Formatter(
+            fmt=utils.QUEUE_LOG_FORMAT,
+            datefmt=utils.QUEUE_DATE_FORMAT,
+        )
+        qh.setFormatter(q_log_formatter)
+        LOG.addHandler(qh)
+
     if not quiet:
         sh = logging.StreamHandler(sys.stdout)
         sh.setFormatter(log_formatter)
@@ -458,11 +473,23 @@ def server(
         trace.setup_tracing(["method", "api"])
     stats.APRSDStats(config)
 
-    try:
-        cl = client.Client(config)
-        cl.client
-    except LoginError:
-        sys.exit(-1)
+    if config["aprs"].get("enabled", True):
+        try:
+            cl = client.Client(config)
+            cl.client
+        except LoginError:
+            sys.exit(-1)
+
+        rx_thread = threads.APRSDRXThread(
+            msg_queues=threads.msg_queues,
+            config=config,
+        )
+        rx_thread.start()
+    else:
+        LOG.info(
+            "APRS network connection Not Enabled in config.  This is"
+            " for setups without internet connectivity.",
+        )
 
     # Create the initial PM singleton and Register plugins
     plugin_manager = plugin.PluginManager(config)
@@ -478,34 +505,28 @@ def server(
         messaging.MsgTrack().load()
 
     packets.PacketList(config=config)
+    packets.WatchList(config=config)
 
-    rx_thread = threads.APRSDRXThread(
-        msg_queues=threads.msg_queues,
-        config=config,
-    )
+    if kissclient.KISSClient.kiss_enabled(config):
+        kcl = kissclient.KISSClient(config=config)
+        # This initializes the client object.
+        kcl.client
 
-    rx_thread.start()
-
-    if "watch_list" in config["aprsd"] and config["aprsd"]["watch_list"].get(
-        "enabled",
-        True,
-    ):
-        packets.WatchList(config=config)
+        kissrx_thread = threads.KISSRXThread(msg_queues=threads.msg_queues, config=config)
+        kissrx_thread.start()
 
     messaging.MsgTrack().restart()
 
     keepalive = threads.KeepAliveThread(config=config)
     keepalive.start()
 
-    try:
-        web_enabled = utils.check_config_option(config, ["aprsd", "web", "enabled"])
-    except Exception:
-        web_enabled = False
+    web_enabled = utils.check_config_option(config, ["aprsd", "web", "enabled"], default_fail=False)
 
     if web_enabled:
         flask_enabled = True
-        app = flask.init_flask(config, loglevel, quiet)
-        app.run(
+        (socketio, app) = flask.init_flask(config, loglevel, quiet)
+        socketio.run(
+            app,
             host=config["aprsd"]["web"]["host"],
             port=config["aprsd"]["web"]["port"],
         )
