@@ -143,7 +143,6 @@ class EmailPlugin(plugin.APRSDRegexCommandPluginBase):
         return reply
 
 
-@trace.trace
 def _imap_connect():
     global CONFIG
     imap_port = CONFIG["aprsd"]["email"]["imap"].get("port", 143)
@@ -184,7 +183,6 @@ def _imap_connect():
     return server
 
 
-@trace.trace
 def _smtp_connect():
     host = CONFIG["aprsd"]["email"]["smtp"]["host"]
     smtp_port = CONFIG["aprsd"]["email"]["smtp"]["port"]
@@ -248,14 +246,14 @@ def validate_shortcuts(config):
         LOG.info(f"Validating {key}:{shortcuts[key]}")
         is_valid = validate_email(
             email_address=shortcuts[key],
-            check_regex=True,
-            check_mx=False,
-            from_address=config["aprsd"]["email"]["smtp"]["login"],
-            helo_host=config["aprsd"]["email"]["smtp"]["host"],
+            check_format=True,
+            check_dns=True,
+            check_smtp=True,
+            smtp_from_address=config["aprsd"]["email"]["smtp"]["login"],
+            smtp_helo_host=config["aprsd"]["email"]["smtp"]["host"],
             smtp_timeout=10,
             dns_timeout=10,
-            use_blacklist=True,
-            debug=False,
+            smtp_debug=False,
         )
         if not is_valid:
             LOG.error(
